@@ -11,16 +11,25 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+from __future__ import annotations
 from typing import Optional
 
+import client
 
 class ResourceRequest:
     """
-    The resource requirement and replicas requests for model version endpoint.
+    The resource requirement and replicas requests for Merlin components (e.g. version endpoint, batch prediction job, image builder).
     """
 
-    def __init__(self, min_replica: int, max_replica: int, cpu_request: str, memory_request: str, gpu_request: str=None, gpu_name: str=None):
+    def __init__(
+        self,
+        min_replica: Optional[int] = None,
+        max_replica: Optional[int] = None,
+        cpu_request: Optional[str] = None,
+        memory_request: Optional[str] = None,
+        gpu_request: Optional[str] = None,
+        gpu_name: Optional[str] = None,
+    ):
         self._min_replica = min_replica
         self._max_replica = max_replica
         self._cpu_request = cpu_request
@@ -29,8 +38,19 @@ class ResourceRequest:
         self._gpu_name = gpu_name
         self.validate()
 
+    @classmethod
+    def from_response(cls, response: client.ResourceRequest) -> ResourceRequest:
+        return ResourceRequest(
+            min_replica=response.min_replica,
+            max_replica=response.max_replica,
+            cpu_request=response.cpu_request,
+            memory_request=response.memory_request,
+            gpu_request=response.gpu_request,
+            gpu_name=response.gpu_name
+        )
+
     @property
-    def min_replica(self) -> int:
+    def min_replica(self) -> Optional[int]:
         return self._min_replica
 
     @min_replica.setter
@@ -38,7 +58,7 @@ class ResourceRequest:
         self._min_replica = min_replica
 
     @property
-    def max_replica(self) -> int:
+    def max_replica(self) -> Optional[int]:
         return self._max_replica
 
     @max_replica.setter
@@ -46,7 +66,7 @@ class ResourceRequest:
         self._max_replica = max_replica
 
     @property
-    def cpu_request(self) -> str:
+    def cpu_request(self) -> Optional[str]:
         return self._cpu_request
 
     @cpu_request.setter
@@ -54,7 +74,7 @@ class ResourceRequest:
         self._cpu_request = cpu_request
 
     @property
-    def memory_request(self) -> str:
+    def memory_request(self) -> Optional[str]:
         return self._memory_request
 
     @memory_request.setter
@@ -78,5 +98,8 @@ class ResourceRequest:
         self._gpu_name = gpu_name
 
     def validate(self):
+        if self._min_replica is None and self._max_replica is None:
+            return 
+
         if self._min_replica > self._max_replica:
             raise Exception("Min replica must be less or equal to max replica")
