@@ -22,6 +22,8 @@ from merlin.logger import Logger, LoggerConfig, LoggerMode
 from merlin.model import ModelType
 from merlin.resource_request import ResourceRequest
 from merlin.transformer import StandardTransformer, Transformer
+from merlin.model_schema import ModelSchema
+from merlin.observability.inference import InferenceSchema, ValueType, BinaryClassificationOutput
 from recursive_diff import recursive_eq
 
 import merlin
@@ -76,6 +78,13 @@ def test_model_version_with_labels(
     )
     assert len(should_not_exist_versions) == 0
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 @pytest.mark.dependency()
@@ -107,6 +116,13 @@ def test_sklearn(
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 @pytest.mark.dependency()
@@ -139,6 +155,69 @@ def test_xgboost(
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
+
+@pytest.mark.integration
+@pytest.mark.dependency()
+@pytest.mark.parametrize(
+    "deployment_mode", [DeploymentMode.RAW_DEPLOYMENT, DeploymentMode.SERVERLESS]
+)
+def test_model_schema(
+    integration_test_url, project_name, deployment_mode, use_google_oauth, requests
+):
+    merlin.set_url(integration_test_url, use_google_oauth=use_google_oauth)
+    merlin.set_project(project_name)
+    merlin.set_model(
+        f"model-schema-{deployment_mode_suffix(deployment_mode)}", ModelType.XGBOOST
+    )
+
+    model_dir = "test/xgboost-model"
+
+    undeploy_all_version()
+    model_schema = ModelSchema(spec=InferenceSchema(
+        feature_types={
+            "featureA": ValueType.FLOAT64,
+            "featureB": ValueType.INT64,
+            "featureC": ValueType.STRING,
+            "featureD": ValueType.BOOLEAN
+        },
+        model_prediction_output=BinaryClassificationOutput(
+            prediction_score_column="score",
+            actual_score_column="actual",
+            positive_class_label="completed",
+            negative_class_label="non_complete",
+            score_threshold=0.7
+        )
+    ))
+
+    with merlin.new_model_version(model_schema=model_schema) as v:
+        # Upload the serialized model to MLP
+        merlin.log_model(model_dir=model_dir)
+
+    assert v.model_schema.spec == model_schema.spec
+    
+    endpoint = merlin.deploy(v, deployment_mode=deployment_mode)
+    resp = requests.post(f"{endpoint.url}", json=request_json)
+
+    assert resp.status_code == 200
+    assert resp.json() is not None
+    assert len(resp.json()["predictions"]) == len(request_json["instances"])
+
+    merlin.undeploy(v)
+
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 def test_mlflow_tracking(
@@ -187,6 +266,13 @@ def test_mlflow_tracking(
         # artifact_dir = os.listdir('test/downloaded_artifact')
         # assert len(artifact_dir) > 0  # not empty directory
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 @pytest.mark.dependency()
@@ -219,6 +305,13 @@ def test_tensorflow(
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.pytorch
 @pytest.mark.integration
@@ -244,6 +337,13 @@ def test_pytorch(integration_test_url, project_name, use_google_oauth, requests)
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.serving
 @pytest.mark.integration
@@ -285,6 +385,13 @@ def test_set_traffic(integration_test_url, project_name, use_google_oauth, reque
     # Undeploy other running model version endpoints
     undeploy_all_version()
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.serving
 @pytest.mark.integration
@@ -326,6 +433,13 @@ def test_serve_traffic(integration_test_url, project_name, use_google_oauth, req
     # Undeploy other running model version endpoints
     undeploy_all_version()
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 def test_multi_env(integration_test_url, project_name, use_google_oauth, requests):
@@ -356,6 +470,13 @@ def test_multi_env(integration_test_url, project_name, use_google_oauth, request
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 @pytest.mark.parametrize(
@@ -399,6 +520,13 @@ def test_resource_request(
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.gpu
 @pytest.mark.integration
@@ -497,6 +625,13 @@ def test_logger(
 
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.customtransformer
 @pytest.mark.integration
@@ -671,6 +806,13 @@ def test_standard_transformer_without_feast(
     )  # asserts lhs = rhs, with tolerance
     merlin.undeploy(v)
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.feast
 @pytest.mark.integration
@@ -924,6 +1066,13 @@ def test_custom_model_without_artifact(
     # Undeploy other running model version endpoints
     undeploy_all_version()
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 @pytest.mark.parametrize(
@@ -961,6 +1110,13 @@ def test_custom_model_with_artifact(
     # Undeploy other running model version endpoints
     undeploy_all_version()
 
+    print(f"Deleting model version created...")
+    try:
+        v.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.raw_deployment
 @pytest.mark.integration
@@ -1047,6 +1203,14 @@ def test_deployment_mode_for_serving_model(
     merlin.stop_serving_traffic(model_endpoint.environment_name)
     undeploy_all_version()
 
+    print(f"Deleting model version created...")
+    try:
+        v1.delete_model_version()
+        v2.delete_model_version()
+    except Exception as e:
+        print(e)
+    print(f"Model version deleted.")
+
 
 @pytest.mark.integration
 def test_redeploy_model(integration_test_url, project_name, use_google_oauth, requests):
@@ -1056,14 +1220,13 @@ def test_redeploy_model(integration_test_url, project_name, use_google_oauth, re
 
     merlin.set_url(integration_test_url, use_google_oauth=use_google_oauth)
     merlin.set_project(project_name)
-    merlin.set_model("model-sdk-redeploy", ModelType.TENSORFLOW)
-    model_dir = "test/tensorflow-model"
+    merlin.set_model("model-sdk-redeploy", ModelType.CUSTOM)
 
     undeploy_all_version()
 
     # Upload new model version: v1
     with merlin.new_model_version() as v1:
-        merlin.log_model(model_dir=model_dir)
+        v1.log_custom_model(image="ealen/echo-server:0.5.1", args="--port 8080")
 
     # Deploy using raw_deployment with CPU autoscaling policy
     endpoint = merlin.deploy(
@@ -1074,13 +1237,15 @@ def test_redeploy_model(integration_test_url, project_name, use_google_oauth, re
             metrics_type=merlin.MetricsType.CPU_UTILIZATION, target_value=50
         ),
         deployment_mode=DeploymentMode.RAW_DEPLOYMENT,
+        transformer = Transformer(image="gcr.io/kubeflow-ci/kfserving/image-transformer:latest"),
     )
 
-    resp = requests.post(f"{endpoint.url}", json=tensorflow_request_json)
-
+    with open(os.path.join("test/transformer", "input.json"), "r") as f:
+        req = json.load(f)
+    
+    resp = requests.post(f"{endpoint.url}", json=req)
     assert resp.status_code == 200
     assert resp.json() is not None
-    assert len(resp.json()["predictions"]) == len(tensorflow_request_json["instances"])
 
     # Check the deployment configs of v1
     assert endpoint.resource_request.cpu_request == "123m"
@@ -1092,22 +1257,25 @@ def test_redeploy_model(integration_test_url, project_name, use_google_oauth, re
     assert endpoint.autoscaling_policy.metrics_type == MetricsType.CPU_UTILIZATION
     assert endpoint.autoscaling_policy.target_value == 50
 
+    # Check that the transformer id is set
+    assert endpoint.transformer.id != ""
+
     sleep(10)
 
-    # Deploy v2 using raw_deployment with CPU autoscaling policy
+    # Deploy v2 using raw_deployment with CPU autoscaling policy; update transformer specs.
     new_endpoint = merlin.deploy(
         v1,
         autoscaling_policy=merlin.AutoscalingPolicy(
             metrics_type=merlin.MetricsType.CPU_UTILIZATION, target_value=90
         ),
         deployment_mode=DeploymentMode.RAW_DEPLOYMENT,
+        transformer = Transformer(image="gcr.io/kubeflow-ci/kfserving/image-transformer:latest",
+                                  resource_request=merlin.ResourceRequest(0, 1, "100m", "250Mi")),
     )
 
-    resp = requests.post(f"{new_endpoint.url}", json=tensorflow_request_json)
-
+    resp = requests.post(f"{new_endpoint.url}", json=req)
     assert resp.status_code == 200
     assert resp.json() is not None
-    assert len(resp.json()["predictions"]) == len(tensorflow_request_json["instances"])
 
     # Check that the endpoint remains the same
     assert endpoint.url == new_endpoint.url
@@ -1122,8 +1290,19 @@ def test_redeploy_model(integration_test_url, project_name, use_google_oauth, re
     assert new_endpoint.autoscaling_policy.metrics_type == MetricsType.CPU_UTILIZATION
     assert new_endpoint.autoscaling_policy.target_value == 90
 
+    # Check that the transformer id remains the same
+    assert endpoint.transformer.id == new_endpoint.transformer.id
+
     undeploy_all_version()
 
+    print(f"Deleting model versions created...")
+    for v in merlin.active_model().list_version():
+        try:
+            v.delete_model_version()
+        except Exception as e:
+            print(e)
+    print(f"Model versions deleted.")
+
 
 def deployment_mode_suffix(deployment_mode: DeploymentMode):
     return deployment_mode.value.lower()[0:1]
@@ -1170,11 +1349,14 @@ def test_standard_transformer_simulate(integration_test_url, use_google_oauth):
     resp_wo_tracing = transformer.simulate(payload=payload, exclude_tracing=True)
     resp_w_tracing = transformer.simulate(payload=payload, exclude_tracing=False)
 
+    def remove_nulls(d):
+        return {k: v for k, v in d.items() if v is not None}
+
     with open("test/transformer/sim_exp_resp_valid_wo_tracing.json", "r") as f:
-        exp_resp_valid_wo_tracing = json.load(f)
+        exp_resp_valid_wo_tracing = json.load(f, object_hook=remove_nulls)
 
     with open("test/transformer/sim_exp_resp_valid_w_tracing.json", "r") as f:
-        exp_resp_valid_w_tracing = json.load(f)
+        exp_resp_valid_w_tracing = json.load(f, object_hook=remove_nulls)
 
     assert isinstance(resp_wo_tracing, dict)
     assert isinstance(resp_w_tracing, dict)
