@@ -12,86 +12,119 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import datetime
 import json
 import types
 from unittest.mock import patch
 
 import client
 import client as cl
-import merlin
 import pytest
 from merlin import AutoscalingPolicy, DeploymentMode, MetricsType
-from merlin.autoscaling import (RAW_DEPLOYMENT_DEFAULT_AUTOSCALING_POLICY,
-                                SERVERLESS_DEFAULT_AUTOSCALING_POLICY)
+from merlin.autoscaling import (
+    RAW_DEPLOYMENT_DEFAULT_AUTOSCALING_POLICY,
+    SERVERLESS_DEFAULT_AUTOSCALING_POLICY,
+)
 from merlin.batch.config import PredictionJobConfig, ResultType
 from merlin.batch.job import JobStatus
 from merlin.batch.sink import BigQuerySink, SaveMode
 from merlin.batch.source import BigQuerySource
 from merlin.endpoint import VersionEndpoint
 from merlin.model import ModelType
+from merlin.model_schema import InferenceSchema, ModelSchema, RankingOutput, ValueType
 from merlin.protocol import Protocol
 from urllib3_mock import Responses
 
 responses = Responses("requests.packages.urllib3")
 
-default_resource_request = cl.ResourceRequest(1, 1, "100m", "128Mi")
+default_resource_request = cl.ResourceRequest(
+    min_replica=1, max_replica=1, cpu_request="100m", memory_request="128Mi"
+)
 gpu = cl.GPUConfig(
     name="nvidia-tesla-p4",
     values=["1", "4", "8"],
     resource_type="nvidia.com/gpu",
     node_selector={"cloud.google.com/gke-accelerator": "nvidia-tesla-p4"},
     tolerations=[
-        cl.GPUToleration(key="caraml/nvidia-tesla-p4", operator="Equal", value="enabled", effect="NoSchedule"),
-        cl.GPUToleration(key="nvidia.com/gpu", operator="Equal", value="present", effect="NoSchedule"),
+        cl.GPUToleration(
+            key="caraml/nvidia-tesla-p4",
+            operator="Equal",
+            value="enabled",
+            effect="NoSchedule",
+        ),
+        cl.GPUToleration(
+            key="nvidia.com/gpu", operator="Equal", value="present", effect="NoSchedule"
+        ),
     ],
 )
 
 env_1 = cl.Environment(
-    1, "dev", "cluster-1", True, default_resource_request=default_resource_request
+    id=1,
+    name="dev",
+    cluster="cluster-1",
+    is_default=True,
+    default_resource_request=default_resource_request,
 )
 env_2 = cl.Environment(
-    2, "dev-2", "cluster-2", False, default_resource_request=default_resource_request
+    id=2,
+    name="dev-2",
+    cluster="cluster-2",
+    is_default=False,
+    default_resource_request=default_resource_request,
 )
 env_3 = cl.Environment(
-    3,
-    "dev-3",
-    "cluster-3",
-    False,
+    id=2,
+    name="dev-3",
+    cluster="cluster-3",
+    is_default=False,
     default_resource_request=default_resource_request,
     gpus=[gpu],
 )
 
 ep1 = cl.VersionEndpoint(
-    "1234", 1, "running", "localhost/1", "svc-1", env_1.name, env_1, "grafana.com"
+    id="1234",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_1.name,
+    environment=env_1,
+    monitoring_url="grafana.com",
 )
 ep2 = cl.VersionEndpoint(
-    "4567", 1, "running", "localhost/1", "svc-2", env_2.name, env_2, "grafana.com"
+    id="4567",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-2",
+    environment_name=env_2.name,
+    environment=env_2,
+    monitoring_url="grafana.com",
 )
 ep3 = cl.VersionEndpoint(
-    "1234",
-    1,
-    "running",
-    "localhost/1",
-    "svc-1",
-    env_1.name,
-    env_1,
-    "grafana.com",
+    id="1234",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_1.name,
+    environment=env_1,
+    monitoring_url="grafana.com",
     deployment_mode="raw_deployment",
 )
 ep4 = cl.VersionEndpoint(
-    "1234",
-    1,
-    "running",
-    "localhost/1",
-    "svc-1",
-    env_1.name,
-    env_1,
-    "grafana.com",
+    id="1234",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_1.name,
+    environment=env_1,
+    monitoring_url="grafana.com",
     autoscaling_policy=client.AutoscalingPolicy(
         metrics_type=cl.MetricsType.CPU_UTILIZATION, target_value=10
     ),
 )
-
 resource_request_with_gpu = cl.ResourceRequest(
     min_replica=1,
     max_replica=1,
@@ -101,50 +134,79 @@ resource_request_with_gpu = cl.ResourceRequest(
     gpu_request="1",
 )
 ep5 = cl.VersionEndpoint(
-    "789",
-    1,
-    "running",
-    "localhost/1",
-    "svc-1",
-    env_3.name,
-    env_3,
-    "grafana.com",
+    id="789",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_3.name,
+    environment=env_3,
+    monitoring_url="grafana.com",
     resource_request=resource_request_with_gpu,
 )
-
 upi_ep = cl.VersionEndpoint(
-    "1234",
-    1,
-    "running",
-    "localhost/1",
-    "svc-1",
-    env_1.name,
-    env_1,
-    "grafana.com",
+    id="1234",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_1.name,
+    environment=env_1,
+    monitoring_url="grafana.com",
     protocol=cl.Protocol.UPI_V1,
 )
+observability_enabled_ep = cl.VersionEndpoint(
+    id="7899",
+    version_id=1,
+    status="running",
+    url="localhost/1",
+    service_name="svc-1",
+    environment_name=env_3.name,
+    environment=env_3,
+    monitoring_url="grafana.com",
+    enable_model_observability=True,
+)
 
 rule_1 = cl.ModelEndpointRule(
-    destinations=[cl.ModelEndpointRuleDestination(ep1.id, weight=100)]
+    destinations=[
+        cl.ModelEndpointRuleDestination(version_endpoint_id=ep1.id, weight=100)
+    ]
 )
 rule_2 = cl.ModelEndpointRule(
-    destinations=[cl.ModelEndpointRuleDestination(ep2.id, weight=100)]
+    destinations=[
+        cl.ModelEndpointRuleDestination(version_endpoint_id=ep2.id, weight=100)
+    ]
 )
 mdl_endpoint_1 = cl.ModelEndpoint(
-    1, 1, None, "serving", "localhost/1", rule_1, env_1.name, env_1
+    id=1,
+    model_id=1,
+    model=None,
+    status="serving",
+    url="localhost/1",
+    rule=rule_1,
+    environment_name=env_1.name,
+    environment=env_1,
 )
 mdl_endpoint_2 = cl.ModelEndpoint(
-    2, 1, None, "serving", "localhost/2", rule_2, env_2.name, env_2
+    id=2,
+    model_id=1,
+    model=None,
+    status="serving",
+    url="localhost/2",
+    rule=rule_2,
+    environment_name=env_2.name,
+    environment=env_2,
 )
+
 mdl_endpoint_upi = cl.ModelEndpoint(
-    1,
-    1,
-    None,
-    "serving",
-    "localhost/1",
-    rule_1,
-    env_1.name,
-    env_1,
+    id=1,
+    model_id=1,
+    model=None,
+    status="serving",
+    url="localhost/1",
+    rule=rule_1,
+    environment_name=env_1.name,
+    environment=env_1,
     protocol=cl.Protocol.UPI_V1,
 )
 
@@ -172,7 +234,7 @@ config = {
             "table": "project.dataset.result_table",
             "staging_bucket": "gs://test",
             "result_column": "prediction",
-            "save_mode": "OVERWRITE",
+            "save_mode": 1,
             "options": {
                 "key": "val",
             },
@@ -212,6 +274,12 @@ job_2 = cl.PredictionJob(
 )
 
 
+def serialize_datetime(obj):
+    if isinstance(obj, datetime.datetime):
+        return obj.isoformat()
+    raise TypeError("Type is not serializable")
+
+
 class TestProject:
     secret_1 = cl.Secret(id=1, name="secret-1", data="secret-data-1")
     secret_2 = cl.Secret(id=2, name="secret-2", data="secret-data-2")
@@ -227,7 +295,6 @@ class TestProject:
         )
 
         project.create_secret(self.secret_1.name, self.secret_1.data)
-
         actual_body = json.loads(responses.calls[0].request.body)
         assert actual_body["name"] == self.secret_1.name
         assert actual_body["data"] == self.secret_1.data
@@ -358,6 +425,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(ep1.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(ep1.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -401,6 +475,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(upi_ep.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(upi_ep.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -444,6 +525,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(ep3.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(ep3.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -478,7 +566,8 @@ class TestModelVersion:
         )
         # This is the additional check which deploy makes to determine if there are any existing endpoints associated
         responses.add(
-            "GET", "/v1/models/1/versions/1/endpoint",
+            "GET",
+            "/v1/models/1/versions/1/endpoint",
             body=json.dumps([]),
             status=200,
             content_type="application/json",
@@ -487,6 +576,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(ep4.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(ep4.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -556,6 +652,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(ep1.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(ep1.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -599,6 +702,13 @@ class TestModelVersion:
             status=200,
             content_type="application/json",
         )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/1234",
+            body=json.dumps(ep4.to_dict()),
+            status=200,
+            content_type="application/json",
+        )
         responses.add(
             "GET",
             "/v1/models/1/versions/1/endpoint",
@@ -608,9 +718,12 @@ class TestModelVersion:
         )
 
         # Redeployment (add autoscaling policy and change deployment mode)
-        endpoint = version.deploy(environment_name=env_1.name,
-                                  autoscaling_policy=AutoscalingPolicy(metrics_type=MetricsType.CPU_UTILIZATION,
-                                                                       target_value=10))
+        endpoint = version.deploy(
+            environment_name=env_1.name,
+            autoscaling_policy=AutoscalingPolicy(
+                metrics_type=MetricsType.CPU_UTILIZATION, target_value=10
+            ),
+        )
 
         assert endpoint.id == ep4.id
         assert endpoint.status.value == ep4.status
@@ -642,6 +755,13 @@ class TestModelVersion:
             "POST",
             "/v1/models/1/versions/1/endpoint",
             body=json.dumps(ep5.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/789",
+            body=json.dumps(ep5.to_dict()),
             status=200,
             content_type="application/json",
         )
@@ -661,15 +781,63 @@ class TestModelVersion:
         assert endpoint.environment.cluster == env_3.cluster
         assert endpoint.environment.name == env_3.name
         assert endpoint.deployment_mode == DeploymentMode.SERVERLESS
-        assert (
-            endpoint.resource_request.gpu_name
-            == resource_request_with_gpu.gpu_name
-        )
+        assert endpoint.resource_request.gpu_name == resource_request_with_gpu.gpu_name
         assert (
             endpoint.resource_request.gpu_request
             == resource_request_with_gpu.gpu_request
         )
 
+    @responses.activate
+    def test_deploy_with_model_observability_enabled(self, version):
+        responses.add(
+            "GET",
+            "/v1/environments",
+            body=json.dumps([env_3.to_dict()]),
+            status=200,
+            content_type="application/json",
+        )
+        # This is the additional check which deploy makes to determine if there are any existing endpoints associated
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint",
+            body=json.dumps([]),
+            status=200,
+            content_type="application/json",
+        )
+        responses.add(
+            "POST",
+            "/v1/models/1/versions/1/endpoint",
+            body=json.dumps(observability_enabled_ep.to_dict()),
+            status=201,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint",
+            body=json.dumps([observability_enabled_ep.to_dict()]),
+            status=200,
+            content_type="application/json",
+        )
+        responses.add(
+            "GET",
+            "/v1/models/1/versions/1/endpoint/7899",
+            body=json.dumps(observability_enabled_ep.to_dict()),
+            status=200,
+            content_type="application/json",
+        )
+
+        endpoint = version.deploy(
+            environment_name=env_3.name, enable_model_observability=True
+        )
+
+        assert endpoint.id == observability_enabled_ep.id
+        assert endpoint.status.value == observability_enabled_ep.status
+        assert endpoint.environment_name == observability_enabled_ep.environment_name
+        assert endpoint.environment.cluster == env_3.cluster
+        assert endpoint.environment.name == env_3.name
+        assert endpoint.deployment_mode == DeploymentMode.SERVERLESS
+        assert endpoint.enable_model_observability == True
+
     @responses.activate
     def test_undeploy(self, version):
         responses.add(
@@ -774,7 +942,9 @@ class TestModelVersion:
         responses.add(
             method="GET",
             url="/v1/models/1/versions/1/jobs",
-            body=json.dumps([job_1.to_dict(), job_2.to_dict()]),
+            body=json.dumps(
+                [job_1.to_dict(), job_2.to_dict()], default=serialize_datetime
+            ),
             status=200,
             content_type="application/json",
         )
@@ -796,7 +966,7 @@ class TestModelVersion:
         responses.add(
             "POST",
             "/v1/models/1/versions/1/jobs",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -853,7 +1023,7 @@ class TestModelVersion:
         responses.add(
             "POST",
             "/v1/models/1/versions/1/jobs",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -862,7 +1032,7 @@ class TestModelVersion:
             responses.add(
                 "GET",
                 "/v1/models/1/versions/1/jobs/1",
-                body=json.dumps(job_1.to_dict()),
+                body=json.dumps(job_1.to_dict(), default=serialize_datetime),
                 status=500,
                 content_type="application/json",
             )
@@ -903,7 +1073,7 @@ class TestModelVersion:
         responses.add(
             "POST",
             "/v1/models/1/versions/1/jobs",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -936,7 +1106,7 @@ class TestModelVersion:
             responses.add(
                 "GET",
                 "/v1/models/1/versions/1/jobs/1",
-                body=json.dumps(job_1.to_dict()),
+                body=json.dumps(job_1.to_dict(), default=serialize_datetime),
                 status=500,
                 content_type="application/json",
             )
@@ -945,7 +1115,7 @@ class TestModelVersion:
         responses.add(
             "GET",
             "/v1/models/1/versions/1/jobs/1",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -1006,7 +1176,7 @@ class TestModelVersion:
         responses.add(
             "POST",
             "/v1/models/1/versions/1/jobs",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -1039,7 +1209,7 @@ class TestModelVersion:
             responses.add(
                 "GET",
                 "/v1/models/1/versions/1/jobs/1",
-                body=json.dumps(job_1.to_dict()),
+                body=json.dumps(job_1.to_dict(), default=serialize_datetime),
                 status=500,
                 content_type="application/json",
             )
@@ -1047,7 +1217,7 @@ class TestModelVersion:
         responses.add(
             "GET",
             "/v1/models/1/versions/1/jobs/1",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -1057,7 +1227,7 @@ class TestModelVersion:
             responses.add(
                 "GET",
                 "/v1/models/1/versions/1/jobs/1",
-                body=json.dumps(job_1.to_dict()),
+                body=json.dumps(job_1.to_dict(), default=serialize_datetime),
                 status=500,
                 content_type="application/json",
             )
@@ -1099,7 +1269,7 @@ class TestModelVersion:
         responses.add(
             "POST",
             "/v1/models/1/versions/1/jobs",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -1115,7 +1285,7 @@ class TestModelVersion:
         responses.add(
             "GET",
             "/v1/models/1/versions/1/jobs/1",
-            body=json.dumps(job_1.to_dict()),
+            body=json.dumps(job_1.to_dict(), default=serialize_datetime),
             status=200,
             content_type="application/json",
         )
@@ -1165,7 +1335,53 @@ class TestModelVersion:
 class TestModel:
     v1 = cl.Version(id=1, model_id=1)
     v2 = cl.Version(id=2, model_id=1)
-    v3 = cl.Version(id=3, model_id=1, labels={"model": "T-800"}, python_version="3.7.*")
+    v3 = cl.Version(
+        id=3, model_id=1, labels={"model": "T-800"}, python_version="3.10.*"
+    )
+
+    schema = client.ModelSchema(
+        id=3,
+        model_id=1,
+        spec=client.SchemaSpec(
+            tag_columns=["tags", "extras"],
+            feature_types={
+                "featureA": client.ValueType.FLOAT64,
+                "featureB": client.ValueType.INT64,
+                "featureC": client.ValueType.BOOLEAN,
+                "featureD": client.ValueType.STRING,
+            },
+            model_prediction_output=client.ModelPredictionOutput(
+                client.RankingOutput(
+                    rank_score_column="score",
+                    relevance_score_column="relevance_score",
+                    output_class=client.ModelPredictionOutputClass.RANKINGOUTPUT,
+                )
+            ),
+        ),
+    )
+    merlin_model_schema = ModelSchema(
+        id=3,
+        model_id=1,
+        spec=InferenceSchema(
+            tag_columns=["tags", "extras"],
+            feature_types={
+                "featureA": ValueType.FLOAT64,
+                "featureB": ValueType.INT64,
+                "featureC": ValueType.BOOLEAN,
+                "featureD": ValueType.STRING,
+            },
+            model_prediction_output=RankingOutput(
+                rank_score_column="score", relevance_score_column="relevance_score"
+            ),
+        ),
+    )
+    v4 = cl.Version(
+        id=4,
+        model_id=1,
+        labels={"model": "T-800"},
+        python_version="3.10.*",
+        model_schema=schema,
+    )
 
     @responses.activate
     def test_list_version(self, model):
@@ -1218,24 +1434,27 @@ class TestModel:
 
         endpoints = model.list_endpoint()
         assert len(endpoints) == 2
-        assert endpoints[0].id == str(mdl_endpoint_1.id)
-        assert endpoints[1].id == str(mdl_endpoint_2.id)
+        assert endpoints[0].id == mdl_endpoint_1.id
+        assert endpoints[1].id == mdl_endpoint_2.id
 
     @responses.activate
     def test_new_model_version(self, model):
         responses.add(
             "POST",
             "/v1/models/1/versions",
-            body=json.dumps(self.v3.to_dict()),
-            status=200,
+            body=json.dumps(self.v4.to_dict()),
+            status=201,
             content_type="application/json",
         )
 
-        mv = model.new_model_version(labels={"model": "T-800"})
-        assert mv._python_version == "3.7.*"
-        assert mv._id == 3
+        mv = model.new_model_version(
+            labels={"model": "T-800"}, model_schema=self.merlin_model_schema
+        )
+        assert mv._python_version == "3.10.*"
+        assert mv._id == 4
         assert mv._model._id == 1
         assert mv._labels == {"model": "T-800"}
+        assert mv._model_schema == self.merlin_model_schema
 
     @responses.activate
     def test_serve_traffic(self, model):
@@ -1266,11 +1485,11 @@ class TestModel:
             "POST",
             "/v1/models/1/endpoints",
             body=json.dumps(mdl_endpoint_1.to_dict()),
-            status=200,
+            status=201,
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100}, environment_name=env_1.name)
-        assert endpoint.id == str(mdl_endpoint_1.id)
+        assert endpoint.id == mdl_endpoint_1.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1301,7 +1520,7 @@ class TestModel:
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100}, environment_name=env_1.name)
-        assert endpoint.id == str(mdl_endpoint_1.id)
+        assert endpoint.id == mdl_endpoint_1.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1335,11 +1554,11 @@ class TestModel:
             "POST",
             "/v1/models/1/endpoints",
             body=json.dumps(mdl_endpoint_1.to_dict()),
-            status=200,
+            status=201,
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100}, environment_name=env_1.name)
-        assert endpoint.id == str(mdl_endpoint_1.id)
+        assert endpoint.id == mdl_endpoint_1.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1407,11 +1626,11 @@ class TestModel:
             "POST",
             "/v1/models/1/endpoints",
             body=json.dumps(mdl_endpoint_1.to_dict()),
-            status=200,
+            status=201,
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100})
-        assert endpoint.id == str(mdl_endpoint_1.id)
+        assert endpoint.id == mdl_endpoint_1.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1448,7 +1667,7 @@ class TestModel:
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100})
-        assert endpoint.id == str(mdl_endpoint_1.id)
+        assert endpoint.id == mdl_endpoint_1.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1468,11 +1687,11 @@ class TestModel:
             "POST",
             "/v1/models/1/endpoints",
             body=json.dumps(mdl_endpoint_upi.to_dict()),
-            status=200,
+            status=201,
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100}, environment_name=env_1.name)
-        assert endpoint.id == str(mdl_endpoint_upi.id)
+        assert endpoint.id == mdl_endpoint_upi.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_1.environment_name
         )
@@ -1503,7 +1722,7 @@ class TestModel:
             content_type="application/json",
         )
         endpoint = model.serve_traffic({ve: 100}, environment_name=env_1.name)
-        assert endpoint.id == str(mdl_endpoint_upi.id)
+        assert endpoint.id == mdl_endpoint_upi.id
         assert (
             endpoint.environment_name == env_1.name == mdl_endpoint_upi.environment_name
         )
@@ -1521,25 +1740,3 @@ class TestModel:
         response = model.delete_model()
 
         assert response == 1
-
-
-def test_process_conda_env():
-    # test dict version
-    conda = {
-        "name": "test-env",
-        "channels": ["conda-forge"],
-        "dependencies": [
-            "python=3.7.0",
-            {
-                "pip": ["scikit-learn==x.y.z"],
-            },
-        ],
-    }
-
-    new_conda = merlin.model._process_conda_env(conda_env=conda, python_version="3.7.*")
-    assert "python=3.7.*" in new_conda["dependencies"]
-
-    # test file version
-    conda = "test/pyfunc/env.yaml"
-    new_conda = merlin.model._process_conda_env(conda_env=conda, python_version="3.7.*")
-    assert "python=3.7.*" in new_conda["dependencies"]
